;;; to-pdf.el --- Google Chromeを使ってファイルをPDFに変換する
;;;
;;; Version: 2021/09/25
;;;
;;; Install
;;;  copy to-pdf.el to /usr/share/emacs/site-lisp/.
;;;
;;; Setting
;;;  add to .emacs
;;;  ----
;;;  (require 'to-pdf)
;;;  ----
;;;
;;;  ファイルを開いた状態で
;;;    M-x to-pdf-output
;;;  を実行してください。
;;;  リモートファイルまたはファイルではないバッファ(*scratch*など)ではエラーとなります。
;;;

;;; Code:

(defcustom to-pdf-chrome-path
  "/cygdrive/c/Program Files (x86)/Google/Chrome/Application/chrome.exe"
  "Chrome executable path"
  :type 'file
  :group 'to-pdf)

(defcustom to-pdf-chrome-print-options '("--headless" "--print-to-pdf-no-header")
  "Chrome commandline options"
  :group 'to-pdf)

(defun to-pdf-output ()
  "Output to pdf by Google Chrome --print-to-pdf"
  (interactive)
  (if (not (executable-find to-pdf-chrome-path))
      (message (format "Error: executable(%s) is not found." to-pdf-chrome-path))
    (let ((filename (buffer-file-name)))
      (if (and  filename
                (not (file-remote-p filename))
                (file-readable-p filename))
          (let ((fname (if (eq system-type 'cygwin)
                           (cygwin-convert-file-name-to-windows filename)
                         filename))
                )
            (apply #'call-process
                   to-pdf-chrome-path nil nil nil
                   (append to-pdf-chrome-print-options
                           (list (format "--print-to-pdf=%s.pdf" fname))
                           (list (format "file://%s" fname))))
            (message (format "Write to %s.pdf" fname))
            )
        (message (format "Error: file(%s) is not readable" filename))
        ))
    ))

(provide 'to-pdf)
